@@ -4,7 +4,7 @@ use tui::{
   buffer::Buffer,
   layout::{Alignment, Rect},
   style::{Modifier, Style},
-  text::{Span, Spans, Text},
+  text::{Span, Line, Text},
   widgets::{Block, BorderType, Borders, Clear, Paragraph, Widget},
 };
 
@@ -34,7 +34,7 @@ impl Default for Help {
 
 impl Widget for &Help {
   fn render(self, area: Rect, buf: &mut Buffer) {
-    let text: Vec<Spans> = TEXT.lines().map(|line| Spans::from(format!("{}\n", line))).collect();
+    let text: Vec<Line> = TEXT.lines().map(|line| Line::from(format!("{}\n", line))).collect();
     Paragraph::new(text)
       .block(
         Block::default()
